==> hledger-iadd-1.3.21-70-x86_64.pkg.tar.zst: usr/share/haskell/register/hledger-iadd.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hledger-iadd
version:              1.3.21
visibility:           public
id:                   hledger-iadd-1.3.21-Dc2OHFMWboiG57Yt46bJtZ
key:                  hledger-iadd-1.3.21-Dc2OHFMWboiG57Yt46bJtZ
license:              BSD-3-Clause
copyright:            2018 Hans-Peter Deifel
maintainer:           Hans-Peter Deifel <hpd@hpdeifel.de>
author:               Hans-Peter Deifel <hpd@hpdeifel.de>
homepage:             https://github.com/hpdeifel/hledger-iadd#readme
synopsis:             A terminal UI as drop-in replacement for hledger add
description:
    This is a terminal UI as drop-in replacement for hledger add.

    It improves in the following ways on hledger'\''s add command:

    * Interactive as-you-type completion for
    account names and descriptions with optional
    fuzzy matching.

    * Integrated calculator: Amounts can be written
    as simple sums with real-time feedback on the
    result.

    * All actions while entering a transaction can
    be undone

    * Configurable format for date input. Instead
    of @y\/m\/d@ it is also possible to use other
    formats like the german @d.m.y@.

category:             Finance, Console
abi:                  f0c694c3075a6ebde7e24020dc7b0996
exposed:              True
exposed-modules:
    AmountParser Brick.Widgets.BetterDialog Brick.Widgets.Border.Utils
    Brick.Widgets.CommentDialog Brick.Widgets.Edit.EmacsBindings
    Brick.Widgets.HelpMessage Brick.Widgets.List.Utils
    Brick.Widgets.WrappedText ConfigParser Data.Time.Ext DateParser
    Model View

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hledger-iadd-1.3.21
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hledger-iadd-1.3.21
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hledger-iadd-1.3.21
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hledger-iadd
hs-libraries:         HShledger-iadd-1.3.21-Dc2OHFMWboiG57Yt46bJtZ
depends:
    base-4.17.2.1 brick-2.4-AZa7PNzYcykGoGsEthSxiJ containers-0.6.7
    directory-1.3.7.1 free-5.2-243WTtvOq1IHyhUeMp2clo
    hledger-lib-1.42-JNk5MoLRcrIIZHa2Bjx8mL
    megaparsec-9.7.0-EiOytuystFBC1v5RoiaLHB
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    microlens-mtl-0.2.1.0-LWyutRK1cqlCk2SYzoFhAy
    microlens-th-0.4.3.17-GRXwDxs8Aw09PQskuAg669
    optparse-applicative-0.18.1.0-G3Jl5lNMtd03bbRRexh6Dm text-2.0.2
    text-zipper-0.13-F5P8GG48IP71d02OLLseap time-1.12.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-Iia3zhz8DVL3Efh3E6ja96
    vector-0.13.2.0-89nHvRrlFmk5zBBEvFgHzR
    vty-6.2-2iutayfbxnI4jlz4kVUD0q
    xdg-basedir-0.2.2-GUgbFy73ZJ02w1NqlBIm8a

haddock-interfaces:   /usr/share/doc/hledger-iadd/html/hledger-iadd.haddock
haddock-html:         /usr/share/doc/hledger-iadd/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hledger-iadd-1.3.21-71-x86_64.pkg.tar.zst: usr/share/haskell/register/hledger-iadd.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hledger-iadd
version:              1.3.21
visibility:           public
id:                   hledger-iadd-1.3.21-97Z00DSbwdRCI7EsXs4iOu
key:                  hledger-iadd-1.3.21-97Z00DSbwdRCI7EsXs4iOu
license:              BSD-3-Clause
copyright:            2018 Hans-Peter Deifel
maintainer:           Hans-Peter Deifel <hpd@hpdeifel.de>
author:               Hans-Peter Deifel <hpd@hpdeifel.de>
homepage:             https://github.com/hpdeifel/hledger-iadd#readme
synopsis:             A terminal UI as drop-in replacement for hledger add
description:
    This is a terminal UI as drop-in replacement for hledger add.

    It improves in the following ways on hledger'\''s add command:

    * Interactive as-you-type completion for
    account names and descriptions with optional
    fuzzy matching.

    * Integrated calculator: Amounts can be written
    as simple sums with real-time feedback on the
    result.

    * All actions while entering a transaction can
    be undone

    * Configurable format for date input. Instead
    of @y\/m\/d@ it is also possible to use other
    formats like the german @d.m.y@.

category:             Finance, Console
abi:                  ed2833eaaed5503c68e946f90227e45b
exposed:              True
exposed-modules:
    AmountParser Brick.Widgets.BetterDialog Brick.Widgets.Border.Utils
    Brick.Widgets.CommentDialog Brick.Widgets.Edit.EmacsBindings
    Brick.Widgets.HelpMessage Brick.Widgets.List.Utils
    Brick.Widgets.WrappedText ConfigParser Data.Time.Ext DateParser
    Model View

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hledger-iadd-1.3.21
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hledger-iadd-1.3.21
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hledger-iadd-1.3.21
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hledger-iadd
hs-libraries:         HShledger-iadd-1.3.21-97Z00DSbwdRCI7EsXs4iOu
depends:
    base-4.17.2.1 brick-2.4-AZa7PNzYcykGoGsEthSxiJ containers-0.6.7
    directory-1.3.7.1 free-5.2-243WTtvOq1IHyhUeMp2clo
    hledger-lib-1.42.1-E4d6tfZGLXLJ6Fc2tqvo6I
    megaparsec-9.7.0-EiOytuystFBC1v5RoiaLHB
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    microlens-mtl-0.2.1.0-LWyutRK1cqlCk2SYzoFhAy
    microlens-th-0.4.3.17-GRXwDxs8Aw09PQskuAg669
    optparse-applicative-0.18.1.0-G3Jl5lNMtd03bbRRexh6Dm text-2.0.2
    text-zipper-0.13-F5P8GG48IP71d02OLLseap time-1.12.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-Iia3zhz8DVL3Efh3E6ja96
    vector-0.13.2.0-89nHvRrlFmk5zBBEvFgHzR
    vty-6.2-2iutayfbxnI4jlz4kVUD0q
    xdg-basedir-0.2.2-GUgbFy73ZJ02w1NqlBIm8a

haddock-interfaces:   /usr/share/doc/hledger-iadd/html/hledger-iadd.haddock
haddock-html:         /usr/share/doc/hledger-iadd/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
